@@ -5,9 +5,13 @@ from pydantic.fields import Field
 
 
 class Payment(BaseModel):
+    """
+    Class for Payment model
+    `date` and `pay_date` are dates in format: 'DD.MM.YYYY HH:MM:SS' or blank strings
+    """
 
-    id: int = Field(..., alias='transaction_id')
-    pay_id: int
+    id: int = Field(..., alias='pay_id')
+    transaction_id: int
     status: str
     method: str
     amount: int | float
